==> projen-0.45.3-sources.jar: io/github/cdklabs/projen/java/MavenCompile.java <==
package io.github.cdklabs.projen.java;

/**
 * (experimental) Adds the maven-compiler plugin to a POM file and the `compile` task.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.47.0 (build 86d2c33)", date = "2021-12-20T00:39:28.805Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
@software.amazon.jsii.Jsii(module = io.github.cdklabs.projen.$Module.class, fqn = "projen.java.MavenCompile")
public class MavenCompile extends io.github.cdklabs.projen.Component {

    protected MavenCompile(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected MavenCompile(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * @param project This parameter is required.
     * @param pom This parameter is required.
     * @param options
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public MavenCompile(final @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.Project project, final @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.java.Pom pom, final @org.jetbrains.annotations.Nullable io.github.cdklabs.projen.java.MavenCompileOptions options) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(project, "project is required"), java.util.Objects.requireNonNull(pom, "pom is required"), options });
    }

    /**
     * @param project This parameter is required.
     * @param pom This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public MavenCompile(final @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.Project project, final @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.java.Pom pom) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(project, "project is required"), java.util.Objects.requireNonNull(pom, "pom is required") });
    }

    /**
     * (experimental) A fluent builder for {@link io.github.cdklabs.projen.java.MavenCompile}.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static final class Builder implements software.amazon.jsii.Builder<io.github.cdklabs.projen.java.MavenCompile> {
        /**
         * @return a new instance of {@link Builder}.
         * @param project This parameter is required.
         * @param pom This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public static Builder create(final io.github.cdklabs.projen.Project project, final io.github.cdklabs.projen.java.Pom pom) {
            return new Builder(project, pom);
        }

        private final io.github.cdklabs.projen.Project project;
        private final io.github.cdklabs.projen.java.Pom pom;
        private io.github.cdklabs.projen.java.MavenCompileOptions.Builder options;

        private Builder(final io.github.cdklabs.projen.Project project, final io.github.cdklabs.projen.java.Pom pom) {
            this.project = project;
            this.pom = pom;
        }

        /**
         * (experimental) Source language version.
         * <p>
         * Default: "1.8"
         * <p>
         * @return {@code this}
         * @param source Source language version. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder source(final java.lang.String source) {
            this.options().source(source);
            return this;
        }

        /**
         * (experimental) Target JVM version.
         * <p>
         * Default: "1.8"
         * <p>
         * @return {@code this}
         * @param target Target JVM version. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder target(final java.lang.String target) {
            this.options().target(target);
            return this;
        }

        /**
         * @returns a newly built instance of {@link io.github.cdklabs.projen.java.MavenCompile}.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public io.github.cdklabs.projen.java.MavenCompile build() {
            return new io.github.cdklabs.projen.java.MavenCompile(
                this.project,
                this.pom,
                this.options != null ? this.options.build() : null
            );
        }

        private io.github.cdklabs.projen.java.MavenCompileOptions.Builder options() {
            if (this.options == null) {
                this.options = new io.github.cdklabs.projen.java.MavenCompileOptions.Builder();
            }
            return this.options;
        }
    }
}

==> projen-0.79.0-sources.jar: io/github/cdklabs/projen/java/MavenCompile.java <==
package io.github.cdklabs.projen.java;

/**
 * (experimental) Adds the maven-compiler plugin to a POM file and the <code>compile</code> task.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.94.0 (build b380f01)", date = "2024-01-10T23:18:45.491Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
@software.amazon.jsii.Jsii(module = io.github.cdklabs.projen.$Module.class, fqn = "projen.java.MavenCompile")
public class MavenCompile extends io.github.cdklabs.projen.Component {

    protected MavenCompile(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected MavenCompile(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * @param project This parameter is required.
     * @param pom This parameter is required.
     * @param options
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public MavenCompile(final @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.Project project, final @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.java.Pom pom, final @org.jetbrains.annotations.Nullable io.github.cdklabs.projen.java.MavenCompileOptions options) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(project, "project is required"), java.util.Objects.requireNonNull(pom, "pom is required"), options });
    }

    /**
     * @param project This parameter is required.
     * @param pom This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public MavenCompile(final @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.Project project, final @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.java.Pom pom) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(project, "project is required"), java.util.Objects.requireNonNull(pom, "pom is required") });
    }

    /**
     * (experimental) A fluent builder for {@link io.github.cdklabs.projen.java.MavenCompile}.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static final class Builder implements software.amazon.jsii.Builder<io.github.cdklabs.projen.java.MavenCompile> {
        /**
         * @return a new instance of {@link Builder}.
         * @param project This parameter is required.
         * @param pom This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public static Builder create(final io.github.cdklabs.projen.Project project, final io.github.cdklabs.projen.java.Pom pom) {
            return new Builder(project, pom);
        }

        private final io.github.cdklabs.projen.Project project;
        private final io.github.cdklabs.projen.java.Pom pom;
        private io.github.cdklabs.projen.java.MavenCompileOptions.Builder options;

        private Builder(final io.github.cdklabs.projen.Project project, final io.github.cdklabs.projen.java.Pom pom) {
            this.project = project;
            this.pom = pom;
        }

        /**
         * (experimental) Source language version.
         * <p>
         * Default: "1.8"
         * <p>
         * @return {@code this}
         * @param source Source language version. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder source(final java.lang.String source) {
            this.options().source(source);
            return this;
        }

        /**
         * (experimental) Target JVM version.
         * <p>
         * Default: "1.8"
         * <p>
         * @return {@code this}
         * @param target Target JVM version. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder target(final java.lang.String target) {
            this.options().target(target);
            return this;
        }

        /**
         * @return a newly built instance of {@link io.github.cdklabs.projen.java.MavenCompile}.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public io.github.cdklabs.projen.java.MavenCompile build() {
            return new io.github.cdklabs.projen.java.MavenCompile(
                this.project,
                this.pom,
                this.options != null ? this.options.build() : null
            );
        }

        private io.github.cdklabs.projen.java.MavenCompileOptions.Builder options() {
            if (this.options == null) {
                this.options = new io.github.cdklabs.projen.java.MavenCompileOptions.Builder();
            }
            return this.options;
        }
    }
}
